[Libreoffice-commits] core.git: include/vcl vcl/generic vcl/headless vcl/inc vcl/quartz vcl/source vcl/unx vcl/win

Chris Sherlock chris.sherlock79 at gmail.com
Sat Jan 2 22:15:14 PST 2016


 include/vcl/outdev.hxx                  |    2 
 vcl/generic/glyphs/gcach_ftyp.cxx       |    2 
 vcl/generic/print/genpspgraphics.cxx    |    2 
 vcl/headless/svptext.cxx                |    2 
 vcl/inc/cairotextrender.hxx             |    2 
 vcl/inc/generic/genpspgraphics.h        |    2 
 vcl/inc/generic/glyphcache.hxx          |    2 
 vcl/inc/headless/svpgdi.hxx             |    2 
 vcl/inc/outfont.hxx                     |  155 ++++++++++++++++----------------
 vcl/inc/quartz/salgdi.h                 |    4 
 vcl/inc/salgdi.hxx                      |    4 
 vcl/inc/textrender.hxx                  |    2 
 vcl/inc/unx/salgdi.h                    |    4 
 vcl/inc/win/salgdi.h                    |    2 
 vcl/quartz/ctfonts.cxx                  |    4 
 vcl/quartz/salgdi.cxx                   |    2 
 vcl/source/gdi/pdfwriter_impl.hxx       |    2 
 vcl/source/gdi/virdev.cxx               |    2 
 vcl/source/outdev/font.cxx              |   15 +--
 vcl/unx/generic/gdi/cairotextrender.cxx |    2 
 vcl/unx/generic/gdi/salgdi3.cxx         |    2 
 vcl/win/gdi/salgdi3.cxx                 |    2 
 22 files changed, 109 insertions(+), 109 deletions(-)

New commits:
commit 7b974e056df3ad023b18592bc01394943305dc41
Author: Chris Sherlock <chris.sherlock79 at gmail.com>
Date:   Sun Jan 3 15:34:45 2016 +1100

    vcl: merge ImplFontMetricData with ImplFontAttributes
    
    Change-Id: Ia2fe20559745e705667f23cdd73cbe50c6371aaa
    Reviewed-on: https://gerrit.libreoffice.org/21053
    Reviewed-by: Chris Sherlock <chris.sherlock79 at gmail.com>
    Tested-by: Chris Sherlock <chris.sherlock79 at gmail.com>

diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 14e292e..97d26de 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -94,7 +94,7 @@ struct SalTwoRect;
 class VirtualDevice;
 class Printer;
 class FontSelectPattern;
-class ImplFontMetricData;
+class ImplFontAttributes;
 class VCLXGraphics;
 class OutDevStateStack;
 struct BitmapSystemData;
diff --git a/vcl/generic/glyphs/gcach_ftyp.cxx b/vcl/generic/glyphs/gcach_ftyp.cxx
index 7dea18b..093f06d 100644
--- a/vcl/generic/glyphs/gcach_ftyp.cxx
+++ b/vcl/generic/glyphs/gcach_ftyp.cxx
@@ -608,7 +608,7 @@ ServerFont::~ServerFont()
 }
 
 
-void ServerFont::FetchFontMetric( ImplFontMetricData& rTo, long& rFactor ) const
+void ServerFont::FetchFontMetric( ImplFontAttributes& rTo, long& rFactor ) const
 {
     static_cast<ImplFontAttributes&>(rTo) = mpFontInfo->GetFontAttributes();
 
diff --git a/vcl/generic/print/genpspgraphics.cxx b/vcl/generic/print/genpspgraphics.cxx
index 9af2857..f8eb7ed 100644
--- a/vcl/generic/print/genpspgraphics.cxx
+++ b/vcl/generic/print/genpspgraphics.cxx
@@ -911,7 +911,7 @@ void GenPspGraphics::ClearDevFontCache()
     GlyphCache::GetInstance().ClearFontCache();
 }
 
-void GenPspGraphics::GetFontMetric( ImplFontMetricData *pMetric, int )
+void GenPspGraphics::GetFontMetric( ImplFontAttributes *pMetric, int )
 {
     const psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
     psp::PrintFontInfo aInfo;
diff --git a/vcl/headless/svptext.cxx b/vcl/headless/svptext.cxx
index 148c49b..3eb6e92 100644
--- a/vcl/headless/svptext.cxx
+++ b/vcl/headless/svptext.cxx
@@ -27,7 +27,7 @@ sal_uInt16 SvpSalGraphics::SetFont( FontSelectPattern* pIFSD, int nFallbackLevel
     return m_aTextRenderImpl.SetFont(pIFSD, nFallbackLevel);
 }
 
-void SvpSalGraphics::GetFontMetric( ImplFontMetricData* pMetric, int nFallbackLevel )
+void SvpSalGraphics::GetFontMetric( ImplFontAttributes* pMetric, int nFallbackLevel )
 {
     m_aTextRenderImpl.GetFontMetric(pMetric, nFallbackLevel);
 }
diff --git a/vcl/inc/cairotextrender.hxx b/vcl/inc/cairotextrender.hxx
index a40eab0..87a501f 100644
--- a/vcl/inc/cairotextrender.hxx
+++ b/vcl/inc/cairotextrender.hxx
@@ -91,7 +91,7 @@ public:
 
     virtual void                SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16          SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void                GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void                GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool                GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void                GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/generic/genpspgraphics.h b/vcl/inc/generic/genpspgraphics.h
index 947f2ca..286e84b 100644
--- a/vcl/inc/generic/genpspgraphics.h
+++ b/vcl/inc/generic/genpspgraphics.h
@@ -92,7 +92,7 @@ public:
 
     virtual void            SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void            GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void            GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool            GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void            GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/generic/glyphcache.hxx b/vcl/inc/generic/glyphcache.hxx
index 9ebe7f7..9ead91b 100644
--- a/vcl/inc/generic/glyphcache.hxx
+++ b/vcl/inc/generic/glyphcache.hxx
@@ -160,7 +160,7 @@ public:
 
     const FontSelectPattern& GetFontSelData() const      { return maFontSelData; }
 
-    void                    FetchFontMetric( ImplFontMetricData&, long& rFactor ) const;
+    void                    FetchFontMetric( ImplFontAttributes&, long& rFactor ) const;
     const unsigned char*    GetTable( const char* pName, sal_uLong* pLength );
     int                     GetEmUnits() const { return maFaceFT->units_per_EM;}
     double                  GetStretch() { return mfStretch; }
diff --git a/vcl/inc/headless/svpgdi.hxx b/vcl/inc/headless/svpgdi.hxx
index d8cdaf1..d3ed113 100644
--- a/vcl/inc/headless/svpgdi.hxx
+++ b/vcl/inc/headless/svpgdi.hxx
@@ -121,7 +121,7 @@ public:
 
     virtual void            SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void            GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void            GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void            GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/outfont.hxx b/vcl/inc/outfont.hxx
index 50d5137..bba74b6 100644
--- a/vcl/inc/outfont.hxx
+++ b/vcl/inc/outfont.hxx
@@ -38,10 +38,14 @@ namespace vcl { class Font; }
 class ConvertChar;
 class OutputDevice;
 class Size;
+class FontSelectPattern;
 
 class ImplFontAttributes
 {
 public:
+    explicit        ImplFontAttributes() {}
+    explicit        ImplFontAttributes( const FontSelectPattern& );
+
     // device independent font functions
     const OUString& GetFamilyName() const   { return maFamilyName; }
     FontFamily      GetFamilyType() const   { return meFamily; }
@@ -102,82 +106,7 @@ public:
     void            SetSubsettableFlag( bool bSubsettable )     { mbSubsettable = bSubsettable; }
     void            SetOrientationFlag( bool bCanRotate )       { mbOrientation = bCanRotate; }
 
-private:
-    // device independent variables
-    OUString        maFamilyName;               // Font Family Name
-    OUString        maStyleName;                // Font Style Name
-    FontWeight      meWeight;                   // Weight Type
-    FontItalic      meItalic;                   // Slant Type
-    FontFamily      meFamily;                   // Family Type
-    FontPitch       mePitch;                    // Pitch Type
-    FontWidth       meWidthType;                // Width Type
-    bool            mbSymbolFlag;               // Is font a symbol?
-
-    // device dependent variables
-    OUString        maMapNames;                 // List of family name aliases separated with ';'
-    int             mnQuality;                  // Quality (used when similar fonts compete)
-    bool            mbOrientation;              // true: physical font can be rotated
-    bool            mbDevice;                   // true: built in font
-    bool            mbSubsettable;              // true: a subset of the font can be created
-    bool            mbEmbeddable;               // true: the font can be embedded
-};
-
-class FontSelectPatternAttributes : public ImplFontAttributes
-{
-public:
-                    FontSelectPatternAttributes( const vcl::Font&, const OUString& rSearchName,
-                                                 const Size&, float fExactHeight );
-#ifdef WNT
-                    FontSelectPatternAttributes( const PhysicalFontFace&, const Size&,
-                                                 float fExactHeight, int nOrientation, bool bVertical );
-#endif
-
-    size_t          hashCode() const;
-    bool operator==(const FontSelectPatternAttributes& rOther) const;
-    bool operator!=(const FontSelectPatternAttributes& rOther) const
-    {
-        return !(*this == rOther);
-    }
-
-public:
-    OUString        maTargetName;               // name of the font name token that is chosen
-    OUString        maSearchName;               // name of the font that matches best
-    int             mnWidth;                    // width of font in pixel units
-    int             mnHeight;                   // height of font in pixel units
-    float           mfExactHeight;              // requested height (in pixels with subpixel details)
-    int             mnOrientation;              // text orientation in 3600 system
-    LanguageType    meLanguage;                 // text language
-    bool            mbVertical;                 // vertical mode of requested font
-    bool            mbNonAntialiased;           // true if antialiasing is disabled
-
-    bool            mbEmbolden;                 // Force emboldening
-    ItalicMatrix    maItalicMatrix;             // Force matrix for slant
-};
-
-class FontSelectPattern : public FontSelectPatternAttributes
-{
-public:
-                    FontSelectPattern( const vcl::Font&, const OUString& rSearchName,
-                                       const Size&, float fExactHeight );
-#ifdef WNT
-// ifdeffed to prevent it going into unusedcode.easy
-                    FontSelectPattern( const PhysicalFontFace&, const Size&,
-                                       float fExactHeight, int nOrientation, bool bVertical );
-#endif
-
-public: // TODO: change to private
-    const PhysicalFontFace* mpFontData;         // a matching PhysicalFontFace object
-    ImplFontEntry*  mpFontEntry;                // pointer to the resulting FontCache entry
-
-    void            copyAttributes(const FontSelectPatternAttributes &rAttributes);
-};
-
-// - ImplFontMetricData -
-
-class ImplFontMetricData : public ImplFontAttributes
-{
-public:
-    explicit        ImplFontMetricData( const FontSelectPattern& );
+    // Font metrics below
 
     // font instance attributes from the font request
     long            GetWidth()              { return mnWidth; }
@@ -241,10 +170,31 @@ public:
     long            GetDoubleStrikeoutOffset1()         { return mnDStrikeoutOffset1; }
     long            GetDoubleStrikeoutOffset2()         { return mnDStrikeoutOffset2; }
 
+
     void            ImplInitTextLineSize( const OutputDevice* pDev );
     void            ImplInitAboveTextLineSize();
 
 private:
+    // device independent variables
+    OUString        maFamilyName;               // Font Family Name
+    OUString        maStyleName;                // Font Style Name
+    FontWeight      meWeight;                   // Weight Type
+    FontItalic      meItalic;                   // Slant Type
+    FontFamily      meFamily;                   // Family Type
+    FontPitch       mePitch;                    // Pitch Type
+    FontWidth       meWidthType;                // Width Type
+    bool            mbSymbolFlag;               // Is font a symbol?
+
+    // device dependent variables
+    OUString        maMapNames;                 // List of family name aliases separated with ';'
+    int             mnQuality;                  // Quality (used when similar fonts compete)
+    bool            mbOrientation;              // true: physical font can be rotated
+    bool            mbDevice;                   // true: built in font
+    bool            mbSubsettable;              // true: a subset of the font can be created
+    bool            mbEmbeddable;               // true: the font can be embedded
+
+    // Font metrics below
+
     // font instance attributes from the font request
     long            mnWidth;                    // Reference Width
     short           mnOrientation;              // Rotation in 1/10 degrees
@@ -290,6 +240,57 @@ private:
     long            mnDStrikeoutSize;           // Height of double strike-out
     long            mnDStrikeoutOffset1;        // Offset of double strike-out to baseline
     long            mnDStrikeoutOffset2;        // Offset of double strike-out to baseline
+
+};
+
+class FontSelectPatternAttributes : public ImplFontAttributes
+{
+public:
+                    FontSelectPatternAttributes( const vcl::Font&, const OUString& rSearchName,
+                                                 const Size&, float fExactHeight );
+#ifdef WNT
+                    FontSelectPatternAttributes( const PhysicalFontFace&, const Size&,
+                                                 float fExactHeight, int nOrientation, bool bVertical );
+#endif
+
+    size_t          hashCode() const;
+    bool operator==(const FontSelectPatternAttributes& rOther) const;
+    bool operator!=(const FontSelectPatternAttributes& rOther) const
+    {
+        return !(*this == rOther);
+    }
+
+public:
+    OUString        maTargetName;               // name of the font name token that is chosen
+    OUString        maSearchName;               // name of the font that matches best
+    int             mnWidth;                    // width of font in pixel units
+    int             mnHeight;                   // height of font in pixel units
+    float           mfExactHeight;              // requested height (in pixels with subpixel details)
+    int             mnOrientation;              // text orientation in 3600 system
+    LanguageType    meLanguage;                 // text language
+    bool            mbVertical;                 // vertical mode of requested font
+    bool            mbNonAntialiased;           // true if antialiasing is disabled
+
+    bool            mbEmbolden;                 // Force emboldening
+    ItalicMatrix    maItalicMatrix;             // Force matrix for slant
+};
+
+class FontSelectPattern : public FontSelectPatternAttributes
+{
+public:
+                    FontSelectPattern( const vcl::Font&, const OUString& rSearchName,
+                                       const Size&, float fExactHeight );
+#ifdef WNT
+// ifdeffed to prevent it going into unusedcode.easy
+                    FontSelectPattern( const PhysicalFontFace&, const Size&,
+                                       float fExactHeight, int nOrientation, bool bVertical );
+#endif
+
+public: // TODO: change to private
+    const PhysicalFontFace* mpFontData;         // a matching PhysicalFontFace object
+    ImplFontEntry*  mpFontEntry;                // pointer to the resulting FontCache entry
+
+    void            copyAttributes(const FontSelectPatternAttributes &rAttributes);
 };
 
 // - ImplFontEntry -
@@ -306,7 +307,7 @@ public:
 public: // TODO: make data members private
     ImplFontCache * m_pFontCache;
     FontSelectPattern  maFontSelData;           // FontSelectionData
-    ImplFontMetricData  maMetric;               // Font Metric
+    ImplFontAttributes  maMetric;               // Font Metric
     const ConvertChar*  mpConversion;           // used e.g. for StarBats->StarSymbol
 
     long            mnLineHeight;
diff --git a/vcl/inc/quartz/salgdi.h b/vcl/inc/quartz/salgdi.h
index 557e7d6..8b78337 100644
--- a/vcl/inc/quartz/salgdi.h
+++ b/vcl/inc/quartz/salgdi.h
@@ -94,7 +94,7 @@ public:
 
     SalLayout* GetTextLayout( void ) const;
 
-    void       GetFontMetric( ImplFontMetricData& ) const;
+    void       GetFontMetric( ImplFontAttributes& ) const;
     bool       GetGlyphBoundRect( sal_GlyphId, Rectangle& ) const;
     bool       GetGlyphOutline( sal_GlyphId, basegfx::B2DPolyPolygon& ) const;
 
@@ -338,7 +338,7 @@ public:
     // set the font
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
     // get the current font's metrics
-    virtual void            GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void            GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const override;
     virtual bool            GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index 9fd3979..f3c105f 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -41,7 +41,7 @@
 class PhysicalFontCollection;
 class SalBitmap;
 class FontSelectPattern;
-class ImplFontMetricData;
+class ImplFontAttributes;
 class PhysicalFontFace;
 class SalLayout;
 class ImplLayoutArgs;
@@ -145,7 +145,7 @@ public:
     void                        ReleaseFonts() { SetFont( nullptr, 0 ); }
 
     // get the current font's metrics
-    virtual void                GetFontMetric( ImplFontMetricData*, int nFallbackLevel = 0 ) = 0;
+    virtual void                GetFontMetric( ImplFontAttributes*, int nFallbackLevel = 0 ) = 0;
 
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const = 0;
diff --git a/vcl/inc/textrender.hxx b/vcl/inc/textrender.hxx
index 32795fb..938acab 100644
--- a/vcl/inc/textrender.hxx
+++ b/vcl/inc/textrender.hxx
@@ -45,7 +45,7 @@ public:
 
     virtual void                    SetTextColor( SalColor nSalColor ) = 0;
     virtual sal_uInt16              SetFont( FontSelectPattern*, int nFallbackLevel ) = 0;
-    virtual void                    GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) = 0;
+    virtual void                    GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) = 0;
     virtual const FontCharMapPtr    GetFontCharMap() const = 0;
     virtual bool                    GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const = 0;
     virtual void                    GetDevFontList( PhysicalFontCollection* ) = 0;
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index ffe0918..9f93d18 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -36,7 +36,7 @@
 #include <deque>
 #include <memory>
 
-class ImplFontMetricData;
+class ImplFontAttributes;
 class FontSelectPattern;
 class SalBitmap;
 class SalColormap;
@@ -114,7 +114,7 @@ public:
 
     virtual void                    SetTextColor( SalColor nSalColor ) override;
     virtual sal_uInt16              SetFont( FontSelectPattern*, int nFallbackLevel ) override;
-    virtual void                    GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void                    GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     virtual const FontCharMapPtr    GetFontCharMap() const override;
     virtual bool                    GetFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const override;
     virtual void                    GetDevFontList( PhysicalFontCollection* ) override;
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 7372c46..f822d9a 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -363,7 +363,7 @@ public:
     // set the font
     virtual sal_uInt16      SetFont( FontSelectPattern*, int nFallbackLevel ) override;
     // get the current font's metrics
-    virtual void            GetFontMetric( ImplFontMetricData*, int nFallbackLevel ) override;
+    virtual void            GetFontMetric( ImplFontAttributes*, int nFallbackLevel ) override;
     // get the repertoire of the current font
     virtual const FontCharMapPtr GetFontCharMap() const override;
     // get the layout capabilities of the current font
diff --git a/vcl/quartz/salgdi.cxx b/vcl/quartz/salgdi.cxx
index 436890a..ad373ce 100644
--- a/vcl/quartz/salgdi.cxx
+++ b/vcl/quartz/salgdi.cxx
@@ -305,7 +305,7 @@ void AquaSalGraphics::SetTextColor( SalColor nSalColor )
     // SAL_ DEBUG(std::hex << nSalColor << std::dec << "={" << maTextColor.GetRed() << ", " << maTextColor.GetGreen() << ", " << maTextColor.GetBlue() << ", " << maTextColor.GetAlpha() << "}");
 }
 
-void AquaSalGraphics::GetFontMetric( ImplFontMetricData* pMetric, int /*nFallbackLevel*/ )
+void AquaSalGraphics::GetFontMetric( ImplFontAttributes* pMetric, int /*nFallbackLevel*/ )
 {
     mpTextStyle->GetFontMetric( *pMetric );
 }
diff --git a/vcl/source/gdi/pdfwriter_impl.hxx b/vcl/source/gdi/pdfwriter_impl.hxx
index 7d81df8..0e8ab54 100644
--- a/vcl/source/gdi/pdfwriter_impl.hxx
+++ b/vcl/source/gdi/pdfwriter_impl.hxx
@@ -47,7 +47,7 @@
 
 class StyleSettings;
 class FontSelectPattern;
-class ImplFontMetricData;
+class ImplFontAttributes;
 class FontSubsetInfo;
 class ZCodec;
 class EncHashTransporter;
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index 07f476d..1e210cb 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -564,7 +564,7 @@ long VirtualDevice::GetFontExtLeading() const
 #endif
 
     ImplFontEntry*      pEntry = mpFontEntry;
-    ImplFontMetricData* pMetric = &(pEntry->maMetric);
+    ImplFontAttributes* pMetric = &(pEntry->maMetric);
 
     return pMetric->GetExternalLeading();
 }
diff --git a/vcl/source/outdev/font.cxx b/vcl/source/outdev/font.cxx
index f5ab39f..b4dcd2a 100644
--- a/vcl/source/outdev/font.cxx
+++ b/vcl/source/outdev/font.cxx
@@ -188,7 +188,7 @@ FontMetric OutputDevice::GetFontMetric() const
         return aMetric;
 
     ImplFontEntry*      pEntry = mpFontEntry;
-    ImplFontMetricData* pMetric = &(pEntry->maMetric);
+    ImplFontAttributes* pMetric = &(pEntry->maMetric);
 
     // prepare metric
     aMetric.Font::operator=( maFont );
@@ -484,7 +484,7 @@ FontEmphasisMark OutputDevice::ImplGetEmphasisMarkStyle( const vcl::Font& rFont
 long OutputDevice::GetFontExtLeading() const
 {
     ImplFontEntry*      pEntry = mpFontEntry;
-    ImplFontMetricData* pMetric = &(pEntry->maMetric);
+    ImplFontAttributes* pMetric = &(pEntry->maMetric);
 
     return pMetric->GetExternalLeading();
 }
@@ -1739,9 +1739,8 @@ bool ImplFontAttributes::CompareDeviceIndependentFontAttributes(const ImplFontAt
     return true;
 }
 
-ImplFontMetricData::ImplFontMetricData( const FontSelectPattern& rFontSelData )
-    : ImplFontAttributes( rFontSelData )
-    , mnWidth ( rFontSelData.mnWidth)
+ImplFontAttributes::ImplFontAttributes( const FontSelectPattern& rFontSelData )
+    : mnWidth ( rFontSelData.mnWidth)
     , mnOrientation( (short)(rFontSelData.mnOrientation))
     , mnAscent( 0 )
     , mnDescent( 0 )
@@ -1798,7 +1797,7 @@ ImplFontMetricData::ImplFontMetricData( const FontSelectPattern& rFontSelData )
 }
 
 
-void ImplFontMetricData::ImplInitTextLineSize( const OutputDevice* pDev )
+void ImplFontAttributes::ImplInitTextLineSize( const OutputDevice* pDev )
 {
     long nDescent = mnDescent;
     if ( nDescent <= 0 )
@@ -1899,7 +1898,7 @@ void ImplFontMetricData::ImplInitTextLineSize( const OutputDevice* pDev )
 
 }
 
-void ImplFontMetricData::ImplInitAboveTextLineSize()
+void ImplFontAttributes::ImplInitAboveTextLineSize()
 {
     long nIntLeading = mnIntLeading;
     // TODO: assess usage of nLeading below (changed in extleading CWS)
@@ -2199,7 +2198,7 @@ long OutputDevice::GetMinKashida() const
         return 0;
 
     ImplFontEntry*      pEntry = mpFontEntry;
-    ImplFontMetricData* pMetric = &(pEntry->maMetric);
+    ImplFontAttributes* pMetric = &(pEntry->maMetric);
     return ImplDevicePixelToLogicWidth( pMetric->GetMinKashida() );
 }
 
diff --git a/vcl/unx/generic/gdi/cairotextrender.cxx b/vcl/unx/generic/gdi/cairotextrender.cxx
index f758550..29993f5 100644
--- a/vcl/unx/generic/gdi/cairotextrender.cxx
+++ b/vcl/unx/generic/gdi/cairotextrender.cxx
@@ -452,7 +452,7 @@ FontConfigFontOptions* GetFCFontOptions( const ImplFontAttributes& rFontAttribut
 }
 
 void
-CairoTextRender::GetFontMetric( ImplFontMetricData *pMetric, int nFallbackLevel )
+CairoTextRender::GetFontMetric( ImplFontAttributes *pMetric, int nFallbackLevel )
 {
     if( nFallbackLevel >= MAX_FALLBACK )
         return;
diff --git a/vcl/unx/generic/gdi/salgdi3.cxx b/vcl/unx/generic/gdi/salgdi3.cxx
index e7542dd..6c87164 100644
--- a/vcl/unx/generic/gdi/salgdi3.cxx
+++ b/vcl/unx/generic/gdi/salgdi3.cxx
@@ -135,7 +135,7 @@ void X11SalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
 }
 
 void
-X11SalGraphics::GetFontMetric( ImplFontMetricData *pMetric, int nFallbackLevel )
+X11SalGraphics::GetFontMetric( ImplFontAttributes *pMetric, int nFallbackLevel )
 {
     mxTextRenderImpl->GetFontMetric(pMetric, nFallbackLevel);
 }
diff --git a/vcl/win/gdi/salgdi3.cxx b/vcl/win/gdi/salgdi3.cxx
index 4021393..e561e28 100644
--- a/vcl/win/gdi/salgdi3.cxx
+++ b/vcl/win/gdi/salgdi3.cxx
@@ -1479,7 +1479,7 @@ sal_uInt16 WinSalGraphics::SetFont( FontSelectPattern* pFont, int nFallbackLevel
         return 0;
 }
 
-void WinSalGraphics::GetFontMetric( ImplFontMetricData* pMetric, int nFallbackLevel )
+void WinSalGraphics::GetFontMetric( ImplFontAttributes* pMetric, int nFallbackLevel )
 {
     // temporarily change the HDC to the font in the fallback level
     HFONT hOldFont = SelectFont( getHDC(), mhFonts[nFallbackLevel] );


More information about the Libreoffice-commits mailing list
diff --git a/vcl/quartz/ctfonts.cxx b/vcl/quartz/ctfonts.cxx
index a9a70e8..7e97cae 100644
--- a/vcl/quartz/ctfonts.cxx
+++ b/vcl/quartz/ctfonts.cxx
@@ -116,7 +116,7 @@ CoreTextStyle::~CoreTextStyle()
         CFRelease( mpStyleDict );
 }
 
-void CoreTextStyle::GetFontMetric( ImplFontMetricData& rMetric ) const
+void CoreTextStyle::GetFontMetric( ImplFontAttributes& rMetric ) const
 {
     // get the matching CoreText font handle
     // TODO: is it worth it to cache the CTFontRef in SetFont() and reuse it here?
@@ -129,7 +129,7 @@ void CoreTextStyle::GetFontMetric( ImplFontMetricData& rMetric ) const
     rMetric.SetExternalLeading( lrint( CTFontGetLeading( aCTFontRef )) );
     rMetric.SetInternalLeading( lrint( fAscent - fCapHeight ) );
 
     // since ImplFontMetricData::mnWidth is only used for stretching/squeezing fonts
     // setting this width to the pixel height of the fontsize is good enough
     // it also makes the calculation of the stretch factor simple
     rMetric.SetWidth( lrint( CTFontGetSize( aCTFontRef ) * mfFontStretch) );
@@ -129,7 +129,7 @@ void CoreTextStyle::GetFontMetric( ImplFontMetricData& rMetric ) const
     rMetric.SetInternalLeading( lrint( fAscent - fCapHeight ) );
 
-    // since ImplFontMetricData::mnWidth is only used for stretching/squeezing fonts
+    // since ImplFontAttributes::mnWidth is only used for stretching/squeezing fonts
     // setting this width to the pixel height of the fontsize is good enough
     // it also makes the calculation of the stretch factor simple